fn alloc_provenance<'tcx, S: UnderOwnerState<'tcx>>(
s: &S,
alloc_id: AllocId,
) -> ConstantByteProvenanceExpand description
The provenance to give to the bytes of a pointer into the given allocation.
fn alloc_provenance<'tcx, S: UnderOwnerState<'tcx>>(
s: &S,
alloc_id: AllocId,
) -> ConstantByteProvenanceThe provenance to give to the bytes of a pointer into the given allocation.