fn imm_to_raw_bytes<'tcx, S: UnderOwnerState<'tcx>>(
s: &S,
imm: &ImmTy<'tcx>,
) -> Vec<ConstantByte>Expand description
The bytes of an immediate, which is made of at most two scalars.
fn imm_to_raw_bytes<'tcx, S: UnderOwnerState<'tcx>>(
s: &S,
imm: &ImmTy<'tcx>,
) -> Vec<ConstantByte>The bytes of an immediate, which is made of at most two scalars.