pointee_to_const

Function pointee_to_const 

fn pointee_to_const<'tcx, S: UnderOwnerState<'tcx>>(
    s: &S,
    span: Span,
    ecx: &CompileTimeInterpCx<'tcx>,
    place: MPlaceTy<'tcx>,
) -> InterpResult<'tcx, ConstantExpr>
Convert the target of a valid pointer. Pointers to globals are kept as references to these globals, and we fallback to reading the bytes for other cases.