fn op_to_raw_bytes<'tcx, S: UnderOwnerState<'tcx>>(
s: &S,
ecx: &CompileTimeInterpCx<'tcx>,
op: &OpTy<'tcx>,
) -> InterpResult<'tcx, Vec<ConstantByte>>Expand description
Read the raw bytes of an evaluated operand, keeping track of uninitialized bytes and pointer provenance. Used for values that have no structured representation (e.g. unions).